@@ -100,14 +100,8 @@ true ::= 't' 'r' 'u' 'e' => True
 null ::= ('n' 'u' 'l' 'l') => None
 undefined ::= ('u' 'n' 'd' 'e' 'f' 'i' 'n' 'e' 'd') => None
 notdquote ::= <escapedquote>
-    | '\n' => '\\n'
-    | '\r' => '\\r'
-    | '\\' => '\\\\'
     | (~('"') <anything>)
 notsquote ::= <escapedquote>
-    | '\n' => '\\n'
-    | '\r' => '\\r'
-    | '\\' => '\\\\'
     | (~("'") <anything>)
 escapedquote ::= '\\' '"' => '\\"'
     | "\\" "'" => "\\'"
@@ -372,8 +366,8 @@ def prepare(value, should_escape):
                 value = u'true' if value else u'false'
             else:
                 value = str_class(value)
-        if should_escape:
-            value = escape(value)
+        # if should_escape:
+        #     value = escape(value)
     return value
 
 
